#[repr(i32)]pub enum OptionStyle {
Unspecified = 0,
American = 1,
European = 2,
}Expand description
Тип опциона по стилю.
Variants
Unspecified = 0
Тип не определен.
American = 1
Американский опцион.
European = 2
Европейский опцион.
Implementations
Sourceimpl OptionStyle
impl OptionStyle
Sourceimpl OptionStyle
impl OptionStyle
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.