#[repr(i32)]pub enum StopOrderType {
Unspecified = 0,
TakeProfit = 1,
StopLoss = 2,
StopLimit = 3,
}Expand description
Тип стоп-заявки.
Variants
Unspecified = 0
Значение не указано.
TakeProfit = 1
Take-profit-заявка.
StopLoss = 2
Stop-loss-заявка.
StopLimit = 3
Stop-limit-заявка.
Implementations
Sourceimpl StopOrderType
impl StopOrderType
Sourceimpl StopOrderType
impl StopOrderType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.