#[repr(i32)]pub enum StrategyType {
Unspecified = 0,
Technical = 1,
Fundamental = 2,
}Expand description
Тип стратегии.
Variants
Unspecified = 0
Не определен.
Technical = 1
Техническая стратегия.
Fundamental = 2
Фундаментальная стратегия.
Implementations
Sourceimpl StrategyType
impl StrategyType
Sourceimpl StrategyType
impl StrategyType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.