#[repr(i32)]pub enum TradeSourceType {
TradeSourceUnspecified = 0,
TradeSourceExchange = 1,
TradeSourceDealer = 2,
TradeSourceAll = 3,
}Expand description
Типы источников сделок.
Variants
TradeSourceUnspecified = 0
Тип источника сделки не определён.
TradeSourceExchange = 1
Биржевые сделки.
TradeSourceDealer = 2
Сделки дилера.
TradeSourceAll = 3
Все сделки.
Implementations
Sourceimpl TradeSourceType
impl TradeSourceType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.