#[repr(i32)]pub enum TrailingStopStatus {
TrailingStopUnspecified = 0,
TrailingStopActive = 1,
TrailingStopActivated = 2,
}Expand description
Статус трейлинг-стопа.
Variants
TrailingStopUnspecified = 0
Значение не указано.
TrailingStopActive = 1
Активный.
TrailingStopActivated = 2
Активированный.
Implementations
Sourceimpl TrailingStopStatus
impl TrailingStopStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.