#[repr(i32)]pub enum IndicatorInterval {
Show 14 variants
Unspecified = 0,
OneMinute = 1,
FiveMinutes = 2,
FifteenMinutes = 3,
OneHour = 4,
OneDay = 5,
IndicatorInterval2Min = 6,
IndicatorInterval3Min = 7,
IndicatorInterval10Min = 8,
IndicatorInterval30Min = 9,
IndicatorInterval2Hour = 10,
IndicatorInterval4Hour = 11,
Week = 12,
Month = 13,
}Expand description
Интервал свечи.
Variants
Unspecified = 0
Интервал не определен.
OneMinute = 1
1 минута.
FiveMinutes = 2
5 минут.
FifteenMinutes = 3
15 минут.
OneHour = 4
1 час.
OneDay = 5
1 день.
IndicatorInterval2Min = 6
2 минуты.
IndicatorInterval3Min = 7
3 минуты.
IndicatorInterval10Min = 8
10 минут.
IndicatorInterval30Min = 9
30 минут.
IndicatorInterval2Hour = 10
2 часа.
IndicatorInterval4Hour = 11
4 часа.
Week = 12
Неделя.
Month = 13
Месяц.
Implementations
Sourceimpl IndicatorInterval
impl IndicatorInterval
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.