InstrumentsServiceClient

Struct InstrumentsServiceClient 

pub struct InstrumentsServiceClient<T> { /* private fields */ }

Implementations

Source

impl InstrumentsServiceClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> InstrumentsServiceClient<T>
where T: GrpcService<BoxBody>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_origin(inner: T, origin: Uri) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> InstrumentsServiceClient<InterceptedService<T, F>>
where F: Interceptor, T::ResponseBody: Default, T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>, <T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,

pub fn send_compressed(self, encoding: CompressionEncoding) -> Self

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> Self

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> Self

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn trading_schedules( &mut self, request: impl IntoRequest<TradingSchedulesRequest>, ) -> Result<Response<TradingSchedulesResponse>, Status>

Получить расписания торгов торговых площадок

pub async fn bond_by( &mut self, request: impl IntoRequest<InstrumentRequest>, ) -> Result<Response<BondResponse>, Status>

Получить облигации по ее идентификатору

pub async fn bonds( &mut self, request: impl IntoRequest<InstrumentsRequest>, ) -> Result<Response<BondsResponse>, Status>

Получить список облигаций

pub async fn get_bond_coupons( &mut self, request: impl IntoRequest<GetBondCouponsRequest>, ) -> Result<Response<GetBondCouponsResponse>, Status>

Получить график выплат купонов по облигации

pub async fn get_bond_events( &mut self, request: impl IntoRequest<GetBondEventsRequest>, ) -> Result<Response<GetBondEventsResponse>, Status>

Получить события по облигации

pub async fn currency_by( &mut self, request: impl IntoRequest<InstrumentRequest>, ) -> Result<Response<CurrencyResponse>, Status>

Получить валюту по ее идентификатору

pub async fn currencies( &mut self, request: impl IntoRequest<InstrumentsRequest>, ) -> Result<Response<CurrenciesResponse>, Status>

Получить список валют

pub async fn etf_by( &mut self, request: impl IntoRequest<InstrumentRequest>, ) -> Result<Response<EtfResponse>, Status>

Получить инвестиционный фонд по его идентификатору

pub async fn etfs( &mut self, request: impl IntoRequest<InstrumentsRequest>, ) -> Result<Response<EtfsResponse>, Status>

Получить список инвестиционных фондов

pub async fn future_by( &mut self, request: impl IntoRequest<InstrumentRequest>, ) -> Result<Response<FutureResponse>, Status>

Получить фьючерс по его идентификатору

pub async fn futures( &mut self, request: impl IntoRequest<InstrumentsRequest>, ) -> Result<Response<FuturesResponse>, Status>

Получить список фьючерсов

pub async fn option_by( &mut self, request: impl IntoRequest<InstrumentRequest>, ) -> Result<Response<OptionResponse>, Status>

Получить опцион по его идентификатору

pub async fn options( &mut self, request: impl IntoRequest<InstrumentsRequest>, ) -> Result<Response<OptionsResponse>, Status>

👎Deprecated

Deprecated Получить список опционов

pub async fn options_by( &mut self, request: impl IntoRequest<FilterOptionsRequest>, ) -> Result<Response<OptionsResponse>, Status>

Получить список опционов

pub async fn share_by( &mut self, request: impl IntoRequest<InstrumentRequest>, ) -> Result<Response<ShareResponse>, Status>

Получить акцию по ее идентификатору

pub async fn shares( &mut self, request: impl IntoRequest<InstrumentsRequest>, ) -> Result<Response<SharesResponse>, Status>

Получить список акций

pub async fn indicatives( &mut self, request: impl IntoRequest<IndicativesRequest>, ) -> Result<Response<IndicativesResponse>, Status>

Получить индикативные инструменты — индексы, товары и другие

pub async fn get_accrued_interests( &mut self, request: impl IntoRequest<GetAccruedInterestsRequest>, ) -> Result<Response<GetAccruedInterestsResponse>, Status>

Получить накопленный купонный доход по облигации

pub async fn get_futures_margin( &mut self, request: impl IntoRequest<GetFuturesMarginRequest>, ) -> Result<Response<GetFuturesMarginResponse>, Status>

Получить размера гарантийного обеспечения по фьючерсам

pub async fn get_instrument_by( &mut self, request: impl IntoRequest<InstrumentRequest>, ) -> Result<Response<InstrumentResponse>, Status>

Получить основную информацию об инструменте

pub async fn get_dividends( &mut self, request: impl IntoRequest<GetDividendsRequest>, ) -> Result<Response<GetDividendsResponse>, Status>

Получить события выплаты дивидендов по инструменту

pub async fn get_asset_by( &mut self, request: impl IntoRequest<AssetRequest>, ) -> Result<Response<AssetResponse>, Status>

Получить актив по его идентификатору

pub async fn get_assets( &mut self, request: impl IntoRequest<AssetsRequest>, ) -> Result<Response<AssetsResponse>, Status>

Получить список активов. Метод работает для всех инструментов, кроме срочных — фьючерсов и опционов

pub async fn get_favorites( &mut self, request: impl IntoRequest<GetFavoritesRequest>, ) -> Result<Response<GetFavoritesResponse>, Status>

Получить список избранных инструментов

pub async fn edit_favorites( &mut self, request: impl IntoRequest<EditFavoritesRequest>, ) -> Result<Response<EditFavoritesResponse>, Status>

Отредактировать список избранных инструментов

pub async fn create_favorite_group( &mut self, request: impl IntoRequest<CreateFavoriteGroupRequest>, ) -> Result<Response<CreateFavoriteGroupResponse>, Status>

Создать новую группу избранных инструментов

pub async fn delete_favorite_group( &mut self, request: impl IntoRequest<DeleteFavoriteGroupRequest>, ) -> Result<Response<DeleteFavoriteGroupResponse>, Status>

Удалить группу избранных инструментов

pub async fn get_favorite_groups( &mut self, request: impl IntoRequest<GetFavoriteGroupsRequest>, ) -> Result<Response<GetFavoriteGroupsResponse>, Status>

Получить список групп избранных инструментов

pub async fn get_countries( &mut self, request: impl IntoRequest<GetCountriesRequest>, ) -> Result<Response<GetCountriesResponse>, Status>

Получить список стран

pub async fn find_instrument( &mut self, request: impl IntoRequest<FindInstrumentRequest>, ) -> Result<Response<FindInstrumentResponse>, Status>

Найти инструмент

pub async fn get_brands( &mut self, request: impl IntoRequest<GetBrandsRequest>, ) -> Result<Response<GetBrandsResponse>, Status>

Получить список брендов

pub async fn get_brand_by( &mut self, request: impl IntoRequest<GetBrandRequest>, ) -> Result<Response<Brand>, Status>

Получить бренд по его идентификатору

pub async fn get_asset_fundamentals( &mut self, request: impl IntoRequest<GetAssetFundamentalsRequest>, ) -> Result<Response<GetAssetFundamentalsResponse>, Status>

Получить фундаментальные показатели по активу

pub async fn get_asset_reports( &mut self, request: impl IntoRequest<GetAssetReportsRequest>, ) -> Result<Response<GetAssetReportsResponse>, Status>

Получить расписания выхода отчетностей эмитентов

pub async fn get_consensus_forecasts( &mut self, request: impl IntoRequest<GetConsensusForecastsRequest>, ) -> Result<Response<GetConsensusForecastsResponse>, Status>

Получить мнения аналитиков по инструменту

pub async fn get_forecast_by( &mut self, request: impl IntoRequest<GetForecastRequest>, ) -> Result<Response<GetForecastResponse>, Status>

Получить прогнозов инвестдомов по инструменту

pub async fn get_risk_rates( &mut self, request: impl IntoRequest<RiskRatesRequest>, ) -> Result<Response<RiskRatesResponse>, Status>