pub struct GetOperationsByCursorRequest {
pub account_id: String,
pub instrument_id: Option<String>,
pub from: Option<Timestamp>,
pub to: Option<Timestamp>,
pub cursor: Option<String>,
pub limit: Option<i32>,
pub operation_types: Vec<i32>,
pub state: Option<i32>,
pub without_commissions: Option<bool>,
pub without_trades: Option<bool>,
pub without_overnights: Option<bool>,
}Expand description
Запрос списка операций по счету с пагинацией.
Fields
account_id: StringИдентификатор счета клиента, обязательный параметр. Остальные параметры опциональны.
instrument_id: Option<String>Идентификатор инструмента — FIGI или UID инструмента.
from: Option<Timestamp>Начало периода по UTC.
to: Option<Timestamp>Окончание периода по UTC.
cursor: Option<String>Идентификатор элемента, с которого начать формировать ответ.
limit: Option<i32>Лимит количества операций. По умолчанию — 100, максимальное значение — 1000.
operation_types: Vec<i32>Тип операции. Принимает значение из списка OperationType.
state: Option<i32>Статус запрашиваемых операций. Возможные значения указаны в OperationState.
without_commissions: Option<bool>Флаг возврата комиссии. По умолчанию — false.
without_trades: Option<bool>Флаг получения ответа без массива сделок.
without_overnights: Option<bool>Флаг показа overnight операций.
Implementations
Sourceimpl GetOperationsByCursorRequest
impl GetOperationsByCursorRequest
Sourcepub fn instrument_id(&self) -> &str
pub fn instrument_id(&self) -> &str
Returns the value of instrument_id, or the default value if instrument_id is unset.
Sourcepub fn cursor(&self) -> &str
pub fn cursor(&self) -> &str
Returns the value of cursor, or the default value if cursor is unset.
Sourcepub fn operation_types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<OperationType>>
pub fn operation_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<OperationType>>
Returns an iterator which yields the valid enum values contained in operation_types.
Sourcepub fn push_operation_types(&mut self, value: OperationType)
pub fn push_operation_types(&mut self, value: OperationType)
Appends the provided enum value to operation_types.
Sourcepub fn state(&self) -> OperationState
pub fn state(&self) -> OperationState
Returns the enum value of state, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: OperationState)
pub fn set_state(&mut self, value: OperationState)
Sets state to the provided enum value.
Sourcepub fn without_commissions(&self) -> bool
pub fn without_commissions(&self) -> bool
Returns the value of without_commissions, or the default value if without_commissions is unset.
Sourcepub fn without_trades(&self) -> bool
pub fn without_trades(&self) -> bool
Returns the value of without_trades, or the default value if without_trades is unset.
Sourcepub fn without_overnights(&self) -> bool
pub fn without_overnights(&self) -> bool
Returns the value of without_overnights, or the default value if without_overnights is unset.