pub struct GetSignalsRequest {
pub signal_id: Option<String>,
pub strategy_id: Option<String>,
pub strategy_type: Option<i32>,
pub instrument_uid: Option<String>,
pub from: Option<Timestamp>,
pub to: Option<Timestamp>,
pub direction: Option<i32>,
pub active: Option<i32>,
pub paging: Option<Page>,
}Expand description
Запрос сигналов.
Fields
signal_id: Option<String>Идентификатор сигнала.
strategy_id: Option<String>Идентификатор стратегии.
strategy_type: Option<i32>Тип стратегии.
instrument_uid: Option<String>Идентификатор бумаги.
from: Option<Timestamp>Дата начала запрашиваемого интервала по UTC.
to: Option<Timestamp>Дата конца запрашиваемого интервала по UTC.
direction: Option<i32>Направление сигнала.
active: Option<i32>Состояние сигнала.
paging: Option<Page>Настройки пагинации.
Implementations
Sourceimpl GetSignalsRequest
impl GetSignalsRequest
Sourcepub fn signal_id(&self) -> &str
pub fn signal_id(&self) -> &str
Returns the value of signal_id, or the default value if signal_id is unset.
Sourcepub fn strategy_id(&self) -> &str
pub fn strategy_id(&self) -> &str
Returns the value of strategy_id, or the default value if strategy_id is unset.
Sourcepub fn strategy_type(&self) -> StrategyType
pub fn strategy_type(&self) -> StrategyType
Returns the enum value of strategy_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_strategy_type(&mut self, value: StrategyType)
pub fn set_strategy_type(&mut self, value: StrategyType)
Sets strategy_type to the provided enum value.
Sourcepub fn instrument_uid(&self) -> &str
pub fn instrument_uid(&self) -> &str
Returns the value of instrument_uid, or the default value if instrument_uid is unset.
Sourcepub fn direction(&self) -> SignalDirection
pub fn direction(&self) -> SignalDirection
Returns the enum value of direction, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: SignalDirection)
pub fn set_direction(&mut self, value: SignalDirection)
Sets direction to the provided enum value.
Sourcepub fn active(&self) -> SignalState
pub fn active(&self) -> SignalState
Returns the enum value of active, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_active(&mut self, value: SignalState)
pub fn set_active(&mut self, value: SignalState)
Sets active to the provided enum value.