pub struct OrderState {Show 20 fields
pub order_id: String,
pub execution_report_status: i32,
pub lots_requested: i64,
pub lots_executed: i64,
pub initial_order_price: Option<MoneyValue>,
pub executed_order_price: Option<MoneyValue>,
pub total_order_amount: Option<MoneyValue>,
pub average_position_price: Option<MoneyValue>,
pub initial_commission: Option<MoneyValue>,
pub executed_commission: Option<MoneyValue>,
pub figi: String,
pub direction: i32,
pub initial_security_price: Option<MoneyValue>,
pub stages: Vec<OrderStage>,
pub service_commission: Option<MoneyValue>,
pub currency: String,
pub order_type: i32,
pub order_date: Option<Timestamp>,
pub instrument_uid: String,
pub order_request_id: String,
}Expand description
Информация о торговом поручении.
Fields
order_id: StringБиржевой идентификатор заявки.
execution_report_status: i32Текущий статус заявки.
lots_requested: i64Запрошено лотов.
lots_executed: i64Исполнено лотов.
initial_order_price: Option<MoneyValue>Начальная цена заявки. Произведение количества запрошенных лотов на цену.
executed_order_price: Option<MoneyValue>Исполненная цена заявки. Произведение средней цены покупки на количество лотов.
total_order_amount: Option<MoneyValue>Итоговая стоимость заявки, включающая все комиссии.
average_position_price: Option<MoneyValue>Средняя цена позиции по сделке.
initial_commission: Option<MoneyValue>Начальная комиссия. Комиссия, рассчитанная на момент подачи заявки.
executed_commission: Option<MoneyValue>Фактическая комиссия по итогам исполнения заявки.
figi: StringFigi-идентификатор инструмента.
direction: i32Направление заявки.
initial_security_price: Option<MoneyValue>Начальная цена за 1 инструмент. Для получения стоимости лота требуется умножить на лотность инструмента.
stages: Vec<OrderStage>Стадии выполнения заявки.
service_commission: Option<MoneyValue>Сервисная комиссия.
currency: StringВалюта заявки.
order_type: i32Тип заявки.
order_date: Option<Timestamp>Дата и время выставления заявки в часовом поясе UTC.
instrument_uid: StringUID идентификатор инструмента.
order_request_id: StringИдентификатор ключа идемпотентности, переданный клиентом, в формате UID. Максимальная длина 36 символов.
Implementations
Sourceimpl OrderState
impl OrderState
Sourcepub fn execution_report_status(&self) -> OrderExecutionReportStatus
pub fn execution_report_status(&self) -> OrderExecutionReportStatus
Returns the enum value of execution_report_status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_execution_report_status(&mut self, value: OrderExecutionReportStatus)
pub fn set_execution_report_status(&mut self, value: OrderExecutionReportStatus)
Sets execution_report_status to the provided enum value.
Sourcepub fn direction(&self) -> OrderDirection
pub fn direction(&self) -> OrderDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: OrderDirection)
pub fn set_direction(&mut self, value: OrderDirection)
Sets direction to the provided enum value.
Sourcepub fn order_type(&self) -> OrderType
pub fn order_type(&self) -> OrderType
Returns the enum value of order_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_order_type(&mut self, value: OrderType)
pub fn set_order_type(&mut self, value: OrderType)
Sets order_type to the provided enum value.