pub struct PostOrderAsyncRequest {
pub instrument_id: String,
pub quantity: i64,
pub price: Option<Quotation>,
pub direction: i32,
pub account_id: String,
pub order_type: i32,
pub order_id: String,
pub time_in_force: Option<i32>,
pub price_type: Option<i32>,
}Expand description
Запрос выставления асинхронного торгового поручения.
Fields
instrument_id: StringИдентификатор инструмента, принимает значения Figi или Instrument_uid.
quantity: i64Количество лотов.
price: Option<Quotation>Цена за 1 инструмент. Для получения стоимости лота требуется умножить на лотность инструмента. Игнорируется для рыночных поручений.
direction: i32Направление операции.
account_id: StringНомер счета.
order_type: i32Тип заявки.
order_id: StringИдентификатор запроса выставления поручения для целей идемпотентности в формате UID. Максимальная длина 36 символов.
time_in_force: Option<i32>Алгоритм исполнения поручения, применяется только к лимитной заявке.
price_type: Option<i32>Тип цены.
Implementations
Sourceimpl PostOrderAsyncRequest
impl PostOrderAsyncRequest
Sourcepub fn direction(&self) -> OrderDirection
pub fn direction(&self) -> OrderDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: OrderDirection)
pub fn set_direction(&mut self, value: OrderDirection)
Sets direction to the provided enum value.
Sourcepub fn order_type(&self) -> OrderType
pub fn order_type(&self) -> OrderType
Returns the enum value of order_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_order_type(&mut self, value: OrderType)
pub fn set_order_type(&mut self, value: OrderType)
Sets order_type to the provided enum value.
Sourcepub fn time_in_force(&self) -> TimeInForceType
pub fn time_in_force(&self) -> TimeInForceType
Returns the enum value of time_in_force, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_time_in_force(&mut self, value: TimeInForceType)
pub fn set_time_in_force(&mut self, value: TimeInForceType)
Sets time_in_force to the provided enum value.
Sourcepub fn price_type(&self) -> PriceType
pub fn price_type(&self) -> PriceType
Returns the enum value of price_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_price_type(&mut self, value: PriceType)
pub fn set_price_type(&mut self, value: PriceType)
Sets price_type to the provided enum value.