pub struct PostOrderResponse {Show 19 fields
pub order_id: String,
pub execution_report_status: i32,
pub lots_requested: i64,
pub lots_executed: i64,
pub initial_order_price: Option<MoneyValue>,
pub executed_order_price: Option<MoneyValue>,
pub total_order_amount: Option<MoneyValue>,
pub initial_commission: Option<MoneyValue>,
pub executed_commission: Option<MoneyValue>,
pub aci_value: Option<MoneyValue>,
pub figi: String,
pub direction: i32,
pub initial_security_price: Option<MoneyValue>,
pub order_type: i32,
pub message: String,
pub initial_order_price_pt: Option<Quotation>,
pub instrument_uid: String,
pub order_request_id: String,
pub response_metadata: Option<ResponseMetadata>,
}Expand description
Информация о выставлении поручения.
Fields
order_id: StringБиржевой идентификатор заявки.
execution_report_status: i32Текущий статус заявки.
lots_requested: i64Запрошено лотов.
lots_executed: i64Исполнено лотов.
initial_order_price: Option<MoneyValue>Начальная цена заявки. Произведение количества запрошенных лотов на цену.
executed_order_price: Option<MoneyValue>Исполненная средняя цена одного инструмента в заявке.
total_order_amount: Option<MoneyValue>Итоговая стоимость заявки, включающая все комиссии.
initial_commission: Option<MoneyValue>Начальная комиссия. Комиссия рассчитанная при выставлении заявки.
executed_commission: Option<MoneyValue>Фактическая комиссия по итогам исполнения заявки.
aci_value: Option<MoneyValue>Значение НКД (накопленного купонного дохода) на дату. Подробнее: НКД при выставлении торговых поручений
figi: StringFigi-идентификатор инструмента.
direction: i32Направление сделки.
initial_security_price: Option<MoneyValue>Начальная цена за 1 инструмент. Для получения стоимости лота требуется умножить на лотность инструмента.
order_type: i32Тип заявки.
message: StringДополнительные данные об исполнении заявки.
initial_order_price_pt: Option<Quotation>Начальная цена заявки в пунктах (для фьючерсов).
instrument_uid: StringUID идентификатор инструмента.
order_request_id: StringИдентификатор ключа идемпотентности, переданный клиентом, в формате UID. Максимальная длина 36 символов.
response_metadata: Option<ResponseMetadata>Метадата
Implementations
Sourceimpl PostOrderResponse
impl PostOrderResponse
Sourcepub fn execution_report_status(&self) -> OrderExecutionReportStatus
pub fn execution_report_status(&self) -> OrderExecutionReportStatus
Returns the enum value of execution_report_status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_execution_report_status(&mut self, value: OrderExecutionReportStatus)
pub fn set_execution_report_status(&mut self, value: OrderExecutionReportStatus)
Sets execution_report_status to the provided enum value.
Sourcepub fn direction(&self) -> OrderDirection
pub fn direction(&self) -> OrderDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: OrderDirection)
pub fn set_direction(&mut self, value: OrderDirection)
Sets direction to the provided enum value.
Sourcepub fn order_type(&self) -> OrderType
pub fn order_type(&self) -> OrderType
Returns the enum value of order_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_order_type(&mut self, value: OrderType)
pub fn set_order_type(&mut self, value: OrderType)
Sets order_type to the provided enum value.