pub struct PostStopOrderRequest {Show 15 fields
pub figi: Option<String>,
pub quantity: i64,
pub price: Option<Quotation>,
pub stop_price: Option<Quotation>,
pub direction: i32,
pub account_id: String,
pub expiration_type: i32,
pub stop_order_type: i32,
pub expire_date: Option<Timestamp>,
pub instrument_id: String,
pub exchange_order_type: i32,
pub take_profit_type: i32,
pub trailing_data: Option<TrailingData>,
pub price_type: i32,
pub order_id: String,
}Expand description
Запрос выставления стоп-заявки.
Fields
figi: Option<String>Deprecated FIGI-идентификатор инструмента. Используйте instrument_id.
quantity: i64Количество лотов.
price: Option<Quotation>Цена за 1 инструмент биржевой заявки, которая будет выставлена при срабатывании по достижению stop_price. Чтобы получить стоимость лота, нужно умножить на лотность инструмента.
stop_price: Option<Quotation>Стоп-цена заявки за 1 инструмент. При достижении стоп-цены происходит активация стоп-заявки, в результате чего выставляется биржевая заявка. Чтобы получить стоимость лота, нужно умножить на лотность инструмента.
direction: i32Направление операции.
account_id: StringНомер счета.
expiration_type: i32Тип экспирации заявки.
stop_order_type: i32Тип заявки.
expire_date: Option<Timestamp>Дата и время окончания действия стоп-заявки по UTC. Для ExpirationType = GoodTillDate заполнение обязательно, для GoodTillCancel игнорируется.
instrument_id: StringИдентификатор инструмента. Принимает значение figi или instrument_uid.
exchange_order_type: i32Тип дочерней биржевой заявки.
take_profit_type: i32Подтип стоп-заявки — TakeProfit.
trailing_data: Option<TrailingData>Массив с параметрами трейлинг-стопа.
price_type: i32Тип цены.
order_id: StringИдентификатор запроса выставления поручения для целей идемпотентности в формате UID. Максимальная длина — 36 символов.
Implementations
Sourceimpl PostStopOrderRequest
impl PostStopOrderRequest
Sourcepub fn direction(&self) -> StopOrderDirection
pub fn direction(&self) -> StopOrderDirection
Returns the enum value of direction, or the default if the field is set to an invalid enum value.
Sourcepub fn set_direction(&mut self, value: StopOrderDirection)
pub fn set_direction(&mut self, value: StopOrderDirection)
Sets direction to the provided enum value.
Sourcepub fn expiration_type(&self) -> StopOrderExpirationType
pub fn expiration_type(&self) -> StopOrderExpirationType
Returns the enum value of expiration_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_expiration_type(&mut self, value: StopOrderExpirationType)
pub fn set_expiration_type(&mut self, value: StopOrderExpirationType)
Sets expiration_type to the provided enum value.
Sourcepub fn stop_order_type(&self) -> StopOrderType
pub fn stop_order_type(&self) -> StopOrderType
Returns the enum value of stop_order_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_stop_order_type(&mut self, value: StopOrderType)
pub fn set_stop_order_type(&mut self, value: StopOrderType)
Sets stop_order_type to the provided enum value.
Sourcepub fn exchange_order_type(&self) -> ExchangeOrderType
pub fn exchange_order_type(&self) -> ExchangeOrderType
Returns the enum value of exchange_order_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_exchange_order_type(&mut self, value: ExchangeOrderType)
pub fn set_exchange_order_type(&mut self, value: ExchangeOrderType)
Sets exchange_order_type to the provided enum value.
Sourcepub fn take_profit_type(&self) -> TakeProfitType
pub fn take_profit_type(&self) -> TakeProfitType
Returns the enum value of take_profit_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_take_profit_type(&mut self, value: TakeProfitType)
pub fn set_take_profit_type(&mut self, value: TakeProfitType)
Sets take_profit_type to the provided enum value.
Sourcepub fn price_type(&self) -> PriceType
pub fn price_type(&self) -> PriceType
Returns the enum value of price_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_price_type(&mut self, value: PriceType)
pub fn set_price_type(&mut self, value: PriceType)
Sets price_type to the provided enum value.